sizeBytes property
Optional expected size in bytes, used only to weight download progress
before the server reports a content-length.
Implementation
final int? sizeBytes;
Optional expected size in bytes, used only to weight download progress
before the server reports a content-length.
final int? sizeBytes;